Crate pax_manifest

Crate pax_manifest 

Re-exports

pub use pax_runtime_api;

Modules

cartridge_generation
code_serialization
constants
parsing
server

Structs

ComponentDefinition
Container for an entire component definition — includes template, settings, event bindings, property definitions, and compiler + reflection metadata
ComponentTemplate
ControlFlowSettingsDefinition
Container for storing parsed control flow information, for example the string (PAXEL) representations of condition / slot / repeat expressions and the related vtable ids (for “punching” during expression compilation)
ExpressionCompilationInfo
ExpressionInfo
HostCrateInfo
Pulled from host Cargo.toml
LiteralBlockDefinition
Container for a parsed Literal object
LocationInfo
Container for holding metadata about original Location in Pax Template Used for source-mapping
NodeLocation
PaxIdentifier
PaxManifest
Definition container for an entire Pax cartridge
PropertyDefinition
PropertyDefinitionFlags
These flags describe the aspects of properties that affect RIL codegen. Properties are divided into modal axes (exactly one value should be true per axis per struct instance) Codegen considers each element of the cartesian product of these axes
TemplateNodeDefinition
Represents an entry within a component template, e.g. a declaration inside a template Each node in a template is represented by exactly one TemplateNodeDefinition, and this is a compile-time concern. Note the difference between compile-time definitions and runtime instances. A compile-time TemplateNodeDefinition corresponds to a single runtime RenderNode instance.
TemplateNodeId
Token
Container for parsed values with optional location information Location is optional in case this token was generated dynamically
TypeDefinition
Describes metadata surrounding a property’s type, gathered from a combination of static & dynamic analysis
TypeId
UniqueTemplateNodeIdentifier

Enums

ControlFlowRepeatPredicateDefinition
Container for holding parsed data describing a Repeat (for) predicate, for example the (elem, i) in for (elem, i) in foo or the elem in for elem in foo
NodeType
Number
PaxExpression
PaxPrimary
PaxType
SettingElement
SettingsBlockElement
TreeIndexPosition
TreeLocation
Unit
ValueDefinition
Container for settings values, storing all possible variants, populated at parse-time and used at compile-time

Constants

IMPORTS_BUILTINS
SUPPORTED_NONNUMERIC_PRIMITIVES
SUPPORTED_NUMERIC_PRIMITIVES

Functions

escape_identifier
get_common_properties_as_property_definitions
get_common_properties_type_ids
get_primitive_type_table

Type Aliases

TypeTable