Container for storing parsed control flow information, for
example the string (PAXEL) representations of condition / slot / repeat
expressions and the related vtable ids (for “punching” during expression compilation)
These flags describe the aspects of properties that affect RIL codegen.
Properties are divided into modal axes (exactly one value should be true per axis per struct instance)
Codegen considers each element of the cartesian product of these axes
Represents an entry within a component template, e.g. a declaration inside a template
Each node in a template is represented by exactly one TemplateNodeDefinition, and this is a compile-time
concern. Note the difference between compile-time definitions and runtime instances.
A compile-time TemplateNodeDefinition corresponds to a single runtime RenderNode instance.
Container for holding parsed data describing a Repeat (for)
predicate, for example the (elem, i) in for (elem, i) in foo or
the elem in for elem in foo